@@ -20,9 +20,6 @@ def download_url(url: str, dest: str, sleep_interval: int):
     if len(os.path.dirname(dest)) > 0:
         os.makedirs(os.path.dirname(dest), exist_ok=True)
 
-    if os.path.isfile(dest) and os.path.getsize(dest) == 0:
-        os.remove(dest)
-
     """Rate limiting."""
     time.sleep(sleep_interval)
 
@@ -30,16 +27,23 @@ def download_url(url: str, dest: str, sleep_interval: int):
     if response.status_code != requests.codes.get("ok"):
         raise response.raise_for_status()
 
-    if (
-        os.path.isfile(dest)
-        and os.path.getsize(dest) == response.headers["Content-length"]
+    dest_ext = response.headers.get("content-type").split("/").pop()
+    dest_file = dest + "." + dest_ext
+
+    if os.path.isfile(dest_file) and os.path.getsize(dest_file) == response.headers.get(
+        "content-length"
     ):
         raise FileExistsError
 
-    with open(dest, "xb") as handle:
-        try:
-            for data in response.iter_content(chunk_size=4194304):
-                handle.write(data)
-            handle.close()
-        except requests.exceptions.RequestException as e:
-            logger.error(e)
+    if os.path.isfile(dest_file) and os.path.getsize(dest_file) == 0:
+        os.remove(dest_file)
+    try:
+        with open(dest_file, "xb") as handle:
+            try:
+                for data in response.iter_content(chunk_size=4194304):
+                    handle.write(data)
+                handle.close()
+            except requests.exceptions.RequestException as e:
+                logger.error(e)
+    except:
+        FileExistsError
