@@ -10,6 +10,10 @@ from snapchat_dl.snapchat_dl import SnapchatDL
 from snapchat_dl.utils import NoStoriesAvailable
 
 
+def teardown_module(module):
+    os.system("rm -rf .test-data")
+
+
 class TestSnapchat_dl(unittest.TestCase):
     """Tests for `snapchat_dl` package."""
 
@@ -22,27 +26,16 @@ class TestSnapchat_dl(unittest.TestCase):
         self.test_url404 = "https://google.com/error.html"
         self.username = "invalidusername"
 
-    def tearDown(self):
-        """Tear down test fixtures."""
-        if os.path.isdir(os.path.join(".test-data", self.username)):
-            shutil.rmtree(os.path.join(".test-data"))
-
     def test_class_init(self):
         """Test snapchat_dl init."""
         self.assertTrue(self.snapchat_dl)
 
-    def test_media_type(self):
-        """Test snapchat_dl media_type."""
-        self.assertEqual(self.snapchat_dl.media_type("IMAGE"), ".jpg")
-        self.assertEqual(self.snapchat_dl.media_type("VIDEO"), ".mp4")
-        self.assertEqual(self.snapchat_dl.media_type("VIDEO_NO_SOUND"), ".mp4")
-
     def test_get_stories_no_stories(self):
         """Test snapchat_dl Stories are not available."""
         with self.assertRaises(NoStoriesAvailable):
             self.snapchat_dl.download("username")
 
-    @mock.patch("snapchat_dl.snapchat_dl.SnapchatDL.stories_response")
+    @mock.patch("snapchat_dl.snapchat_dl.SnapchatDL._api_fetch_story")
     def test_get_stories_ok(self, fake_get):
         """Test snapchat_dl Download."""
 
